
use lazy_static::lazy_static;
use std::collections::HashMap;
use crate::spec::tag::ns::Namespace;

pub struct AttributeMinification {
    pub boolean: bool,
    pub redundant_if_empty: bool,
    pub collapse_and_trim: bool,
    pub default_value: Option<&'static [u8]>,
}

pub enum AttrMapEntry {
    AllNamespaceElements(AttributeMinification),
    SpecificNamespaceElements(HashMap<&'static [u8], AttributeMinification>),
}

pub struct ByNamespace {
    // Make pub so this struct can be statically created in gen/attrs.rs.
    pub html: Option<AttrMapEntry>,
    pub svg: Option<AttrMapEntry>,
}

impl ByNamespace {
    #[inline(always)]
    fn get(&self, ns: Namespace) -> Option<&AttrMapEntry> {
        match ns {
            Namespace::Html => self.html.as_ref(),
            Namespace::Svg => self.svg.as_ref(),
        }
    }
}

pub struct AttrMap(HashMap<&'static [u8], ByNamespace>);

impl AttrMap {
    #[inline(always)]
    pub const fn new(map: HashMap<&'static [u8], ByNamespace>) -> AttrMap {
        AttrMap(map)
    }

    #[inline(always)]
    pub fn get(&self, ns: Namespace, tag: &[u8], attr: &[u8]) -> Option<&AttributeMinification> {
        self.0.get(attr).and_then(|namespaces| namespaces.get(ns)).and_then(|entry| match entry {
            AttrMapEntry::AllNamespaceElements(min) => Some(min),
            AttrMapEntry::SpecificNamespaceElements(map) => map.get(tag),
        })
    }
}


lazy_static! {
  pub static ref ATTRS: AttrMap = {
    let mut m = HashMap::<&'static [u8], ByNamespace>::new();
    m.insert(b"defaultchecked", ByNamespace {
      html: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: true, redundant_if_empty: false, collapse_and_trim: false, default_value: None })),
      svg: None,
    });

    m.insert(b"defaultvalue", ByNamespace {
      html: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
      svg: None,
    });

    m.insert(b"suppresscontenteditablewarning", ByNamespace {
      html: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: true, redundant_if_empty: false, collapse_and_trim: false, default_value: None })),
      svg: None,
    });

    m.insert(b"suppresshydrationwarning", ByNamespace {
      html: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: true, redundant_if_empty: false, collapse_and_trim: false, default_value: None })),
      svg: None,
    });

    m.insert(b"accesskey", ByNamespace {
      html: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
      svg: None,
    });

    m.insert(b"class", ByNamespace {
      html: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: true, default_value: None })),
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"contenteditable", ByNamespace {
      html: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: false, collapse_and_trim: false, default_value: None })),
      svg: None,
    });

    m.insert(b"contextmenu", ByNamespace {
      html: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
      svg: None,
    });

    m.insert(b"dir", ByNamespace {
      html: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
      svg: None,
    });

    m.insert(b"draggable", ByNamespace {
      html: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: false, collapse_and_trim: false, default_value: None })),
      svg: None,
    });

    m.insert(b"hidden", ByNamespace {
      html: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: true, redundant_if_empty: false, collapse_and_trim: false, default_value: None })),
      svg: None,
    });

    m.insert(b"id", ByNamespace {
      html: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"lang", ByNamespace {
      html: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"placeholder", ByNamespace {
      html: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
      svg: None,
    });

    m.insert(b"slot", ByNamespace {
      html: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
      svg: None,
    });

    m.insert(b"spellcheck", ByNamespace {
      html: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: false, collapse_and_trim: false, default_value: None })),
      svg: None,
    });

    m.insert(b"style", ByNamespace {
      html: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: false, collapse_and_trim: false, default_value: None })),
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: false, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"tabindex", ByNamespace {
      html: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"title", ByNamespace {
      html: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
      svg: None,
    });

    m.insert(b"translate", ByNamespace {
      html: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: false, collapse_and_trim: false, default_value: None })),
      svg: None,
    });

    m.insert(b"radiogroup", ByNamespace {
      html: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
      svg: None,
    });

    m.insert(b"role", ByNamespace {
      html: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"about", ByNamespace {
      html: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
      svg: None,
    });

    m.insert(b"datatype", ByNamespace {
      html: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
      svg: None,
    });

    m.insert(b"inlist", ByNamespace {
      html: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: false, collapse_and_trim: false, default_value: None })),
      svg: None,
    });

    m.insert(b"prefix", ByNamespace {
      html: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
      svg: None,
    });

    m.insert(b"property", ByNamespace {
      html: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
      svg: None,
    });

    m.insert(b"resource", ByNamespace {
      html: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
      svg: None,
    });

    m.insert(b"typeof", ByNamespace {
      html: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
      svg: None,
    });

    m.insert(b"vocab", ByNamespace {
      html: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
      svg: None,
    });

    m.insert(b"autocapitalize", ByNamespace {
      html: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
      svg: None,
    });

    m.insert(b"autocorrect", ByNamespace {
      html: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
      svg: None,
    });

    m.insert(b"autosave", ByNamespace {
      html: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
      svg: None,
    });

    m.insert(b"color", ByNamespace {
      html: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"itemprop", ByNamespace {
      html: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
      svg: None,
    });

    m.insert(b"itemscope", ByNamespace {
      html: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: true, redundant_if_empty: false, collapse_and_trim: false, default_value: None })),
      svg: None,
    });

    m.insert(b"itemtype", ByNamespace {
      html: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
      svg: None,
    });

    m.insert(b"itemid", ByNamespace {
      html: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
      svg: None,
    });

    m.insert(b"itemref", ByNamespace {
      html: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
      svg: None,
    });

    m.insert(b"results", ByNamespace {
      html: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
      svg: None,
    });

    m.insert(b"security", ByNamespace {
      html: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
      svg: None,
    });

    m.insert(b"unselectable", ByNamespace {
      html: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: false, collapse_and_trim: false, default_value: None })),
      svg: None,
    });

    m.insert(b"inputmode", ByNamespace {
      html: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: false, collapse_and_trim: false, default_value: None })),
      svg: None,
    });

    m.insert(b"is", ByNamespace {
      html: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
      svg: None,
    });

    m.insert(b"download", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"a", AttributeMinification { boolean: false, redundant_if_empty: false, collapse_and_trim: false, default_value: None });
        m.insert(b"area", AttributeMinification { boolean: false, redundant_if_empty: false, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"href", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"a", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"area", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"base", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"link", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"hreflang", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"a", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"area", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"link", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"media", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"a", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"area", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"link", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"source", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"style", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: Some(b"all") });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"ping", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"a", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"rel", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"a", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"area", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"link", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"target", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"a", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: Some(b"_self") });
        m.insert(b"area", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"base", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"form", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: Some(b"_self") });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"type", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"a", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"button", AttributeMinification { boolean: false, redundant_if_empty: false, collapse_and_trim: false, default_value: Some(b"submit") });
        m.insert(b"embed", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"input", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: Some(b"text") });
        m.insert(b"link", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: Some(b"text/css") });
        m.insert(b"menu", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"object", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"ol", AttributeMinification { boolean: false, redundant_if_empty: false, collapse_and_trim: false, default_value: None });
        m.insert(b"script", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"source", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"style", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: Some(b"text/css") });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"referrerpolicy", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"a", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"iframe", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: Some(b"no-referrer-when-downgrade") });
        m.insert(b"img", AttributeMinification { boolean: false, redundant_if_empty: false, collapse_and_trim: false, default_value: Some(b"no-referrer-when-downgrade") });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"alt", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"area", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"img", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"input", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"coords", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"area", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"shape", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"area", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: Some(b"rect") });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"cite", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"blockquote", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"del", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"ins", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"quote", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"autofocus", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"button", AttributeMinification { boolean: true, redundant_if_empty: false, collapse_and_trim: false, default_value: None });
        m.insert(b"input", AttributeMinification { boolean: true, redundant_if_empty: false, collapse_and_trim: false, default_value: None });
        m.insert(b"keygen", AttributeMinification { boolean: true, redundant_if_empty: false, collapse_and_trim: false, default_value: None });
        m.insert(b"select", AttributeMinification { boolean: true, redundant_if_empty: false, collapse_and_trim: false, default_value: None });
        m.insert(b"textarea", AttributeMinification { boolean: true, redundant_if_empty: false, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"disabled", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"button", AttributeMinification { boolean: true, redundant_if_empty: false, collapse_and_trim: false, default_value: None });
        m.insert(b"fieldset", AttributeMinification { boolean: true, redundant_if_empty: false, collapse_and_trim: false, default_value: None });
        m.insert(b"input", AttributeMinification { boolean: true, redundant_if_empty: false, collapse_and_trim: false, default_value: None });
        m.insert(b"keygen", AttributeMinification { boolean: true, redundant_if_empty: false, collapse_and_trim: false, default_value: None });
        m.insert(b"optgroup", AttributeMinification { boolean: true, redundant_if_empty: false, collapse_and_trim: false, default_value: None });
        m.insert(b"option", AttributeMinification { boolean: true, redundant_if_empty: false, collapse_and_trim: false, default_value: None });
        m.insert(b"select", AttributeMinification { boolean: true, redundant_if_empty: false, collapse_and_trim: false, default_value: None });
        m.insert(b"textarea", AttributeMinification { boolean: true, redundant_if_empty: false, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"form", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"button", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"fieldset", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"input", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"keygen", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"label", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"meter", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"object", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"output", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"select", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"textarea", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"formaction", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"button", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"input", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"formenctype", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"button", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: Some(b"application/x-www-form-urlencoded") });
        m.insert(b"input", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: Some(b"application/x-www-form-urlencoded") });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"formmethod", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"button", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"input", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"formnovalidate", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"button", AttributeMinification { boolean: true, redundant_if_empty: false, collapse_and_trim: false, default_value: None });
        m.insert(b"input", AttributeMinification { boolean: true, redundant_if_empty: false, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"formtarget", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"button", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"input", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"name", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"button", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"fieldset", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"form", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"iframe", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"input", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"keygen", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"map", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"meta", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"object", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"output", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"param", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"select", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"slot", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"textarea", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"value", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"button", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"data", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"input", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"li", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"meter", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"option", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"param", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"progress", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"select", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"textarea", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"height", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"canvas", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"embed", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"iframe", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: Some(b"150") });
        m.insert(b"img", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"input", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"object", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"video", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"width", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"canvas", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"col", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"embed", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"iframe", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: Some(b"300") });
        m.insert(b"img", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"input", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"object", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"video", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"span", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"col", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: Some(b"1") });
        m.insert(b"colgroup", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: Some(b"1") });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"datetime", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"del", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"ins", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"time", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"open", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"details", AttributeMinification { boolean: true, redundant_if_empty: false, collapse_and_trim: false, default_value: None });
        m.insert(b"dialog", AttributeMinification { boolean: true, redundant_if_empty: false, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"src", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"embed", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"iframe", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"img", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"input", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"media", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"script", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"source", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"track", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"acceptcharset", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"form", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"action", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"form", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"autocomplete", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"form", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"input", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"select", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"textarea", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"enctype", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"form", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: Some(b"application/x-www-form-urlencoded") });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"method", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"form", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: Some(b"get") });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"novalidate", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"form", AttributeMinification { boolean: true, redundant_if_empty: false, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"manifest", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"html", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"allow", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"iframe", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"allowfullscreen", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"iframe", AttributeMinification { boolean: true, redundant_if_empty: false, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"allowtransparency", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"iframe", AttributeMinification { boolean: true, redundant_if_empty: false, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"frameborder", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"iframe", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: Some(b"1") });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"marginheight", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"iframe", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"marginwidth", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"iframe", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"sandbox", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"iframe", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"scrolling", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"iframe", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"seamless", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"iframe", AttributeMinification { boolean: true, redundant_if_empty: false, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"srcdoc", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"iframe", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"crossorigin", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"img", AttributeMinification { boolean: false, redundant_if_empty: false, collapse_and_trim: false, default_value: None });
        m.insert(b"input", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"link", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"media", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"script", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: false, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"decoding", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"img", AttributeMinification { boolean: false, redundant_if_empty: false, collapse_and_trim: false, default_value: Some(b"auto") });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"loading", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"img", AttributeMinification { boolean: false, redundant_if_empty: false, collapse_and_trim: false, default_value: Some(b"eager") });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"sizes", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"img", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"link", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"source", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"srcset", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"img", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"source", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"usemap", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"img", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"object", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"accept", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"input", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"capture", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"input", AttributeMinification { boolean: true, redundant_if_empty: false, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"checked", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"input", AttributeMinification { boolean: true, redundant_if_empty: false, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"list", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"input", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"max", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"input", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"meter", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"progress", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"maxlength", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"input", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"textarea", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"min", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"input", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"meter", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"minlength", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"input", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"textarea", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"multiple", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"input", AttributeMinification { boolean: true, redundant_if_empty: false, collapse_and_trim: false, default_value: None });
        m.insert(b"select", AttributeMinification { boolean: true, redundant_if_empty: false, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"pattern", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"input", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"readonly", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"input", AttributeMinification { boolean: true, redundant_if_empty: false, collapse_and_trim: false, default_value: None });
        m.insert(b"textarea", AttributeMinification { boolean: true, redundant_if_empty: false, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"required", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"input", AttributeMinification { boolean: true, redundant_if_empty: false, collapse_and_trim: false, default_value: None });
        m.insert(b"select", AttributeMinification { boolean: true, redundant_if_empty: false, collapse_and_trim: false, default_value: None });
        m.insert(b"textarea", AttributeMinification { boolean: true, redundant_if_empty: false, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"size", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"input", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"select", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"step", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"input", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"onchange", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"input", AttributeMinification { boolean: false, redundant_if_empty: false, collapse_and_trim: false, default_value: None });
        m.insert(b"select", AttributeMinification { boolean: false, redundant_if_empty: false, collapse_and_trim: false, default_value: None });
        m.insert(b"textarea", AttributeMinification { boolean: false, redundant_if_empty: false, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"challenge", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"keygen", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"keytype", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"keygen", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"keyparams", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"keygen", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"htmlfor", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"label", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"output", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"as", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"link", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"integrity", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"link", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"script", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"charset", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"link", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"meta", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"script", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"autoplay", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"media", AttributeMinification { boolean: true, redundant_if_empty: false, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"controls", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"media", AttributeMinification { boolean: true, redundant_if_empty: false, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"controlslist", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"media", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"loop", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"media", AttributeMinification { boolean: true, redundant_if_empty: false, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"mediagroup", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"media", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"muted", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"media", AttributeMinification { boolean: true, redundant_if_empty: false, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"playsinline", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"media", AttributeMinification { boolean: true, redundant_if_empty: false, collapse_and_trim: false, default_value: None });
        m.insert(b"video", AttributeMinification { boolean: true, redundant_if_empty: false, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"preload", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"media", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"content", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"meta", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"httpequiv", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"meta", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"high", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"meter", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"low", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"meter", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"optimum", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"meter", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"classid", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"object", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"data", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"object", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"wmode", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"object", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"reversed", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"ol", AttributeMinification { boolean: true, redundant_if_empty: false, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"start", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"ol", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"label", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"optgroup", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"option", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"track", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"selected", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"option", AttributeMinification { boolean: true, redundant_if_empty: false, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"async", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"script", AttributeMinification { boolean: true, redundant_if_empty: false, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"defer", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"script", AttributeMinification { boolean: true, redundant_if_empty: false, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"nomodule", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"script", AttributeMinification { boolean: true, redundant_if_empty: false, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"nonce", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"script", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"style", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"scoped", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"style", AttributeMinification { boolean: true, redundant_if_empty: false, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"cellpadding", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"table", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"cellspacing", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"table", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"summary", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"table", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"align", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"td", AttributeMinification { boolean: false, redundant_if_empty: false, collapse_and_trim: false, default_value: None });
        m.insert(b"th", AttributeMinification { boolean: false, redundant_if_empty: false, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"colspan", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"td", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"th", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"headers", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"td", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"th", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"rowspan", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"td", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"th", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"scope", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"td", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"th", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"abbr", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"td", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        m.insert(b"th", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"valign", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"td", AttributeMinification { boolean: false, redundant_if_empty: false, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"cols", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"textarea", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"dirname", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"textarea", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"rows", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"textarea", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"wrap", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"textarea", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"default", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"track", AttributeMinification { boolean: true, redundant_if_empty: false, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"kind", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"track", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"srclang", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"track", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"poster", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"video", AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"disablepictureinpicture", ByNamespace {
      html: Some({
        let mut m = HashMap::<&'static [u8], AttributeMinification>::new();
        m.insert(b"video", AttributeMinification { boolean: true, redundant_if_empty: false, collapse_and_trim: false, default_value: None });
        AttrMapEntry::SpecificNamespaceElements(m)
      }),
      svg: None,
    });

    m.insert(b"accentheight", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"accumulate", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: false, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"additive", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: false, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"alignmentbaseline", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: false, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"allowreorder", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: false, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"alphabetic", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"amplitude", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"arabicform", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: false, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"ascent", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"attributename", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"attributetype", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"autoreverse", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: false, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"azimuth", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"basefrequency", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"baselineshift", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"baseprofile", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"bbox", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"begin", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"bias", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"by", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"calcmode", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"capheight", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"clip", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"clippath", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"clippathunits", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"cliprule", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"colorinterpolation", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"colorinterpolationfilters", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: false, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"colorprofile", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"colorrendering", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"contentscripttype", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"contentstyletype", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"cursor", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"cx", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"cy", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"d", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: true, default_value: None })),
    });

    m.insert(b"decelerate", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"descent", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"diffuseconstant", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"direction", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"display", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"divisor", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"dominantbaseline", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"dur", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"dx", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"dy", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"edgemode", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"elevation", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"enablebackground", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"end", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"exponent", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"externalresourcesrequired", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: false, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"fill", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"fillopacity", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"fillrule", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: false, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"filter", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"filterres", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"filterunits", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"floodcolor", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"floodopacity", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"focusable", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: false, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"fontfamily", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"fontsize", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"fontsizeadjust", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"fontstretch", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"fontstyle", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"fontvariant", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"fontweight", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"format", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"from", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"fx", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"fy", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"g1", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"g2", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"glyphname", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"glyphorientationhorizontal", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"glyphorientationvertical", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"glyphref", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"gradienttransform", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"gradientunits", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"hanging", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"horizadvx", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"horizoriginx", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"ideographic", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"imagerendering", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"in2", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"in", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"intercept", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"k1", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"k2", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"k3", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"k4", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"k", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"kernelmatrix", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"kernelunitlength", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"kerning", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"keypoints", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"keysplines", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"keytimes", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"lengthadjust", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"letterspacing", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"lightingcolor", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"limitingconeangle", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"local", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"markerend", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"markerheight", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"markermid", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"markerstart", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"markerunits", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"markerwidth", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"mask", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"maskcontentunits", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"maskunits", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"mathematical", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"mode", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"numoctaves", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"offset", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"opacity", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"operator", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"order", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"orient", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"orientation", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"origin", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"overflow", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"overlineposition", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"overlinethickness", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"paintorder", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"panose1", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"path", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"pathlength", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"patterncontentunits", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"patterntransform", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"patternunits", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"pointerevents", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"points", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"pointsatx", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"pointsaty", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"pointsatz", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"preservealpha", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: false, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"preserveaspectratio", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"primitiveunits", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"r", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"radius", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"refx", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"refy", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"renderingintent", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"repeatcount", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"repeatdur", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"requiredextensions", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"requiredfeatures", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"restart", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"result", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"rotate", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"rx", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"ry", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"scale", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"seed", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"shaperendering", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"slope", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"spacing", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"specularconstant", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"specularexponent", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"speed", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"spreadmethod", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"startoffset", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"stddeviation", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"stemh", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"stemv", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"stitchtiles", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"stopcolor", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"stopopacity", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"strikethroughposition", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"strikethroughthickness", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"string", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"stroke", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"strokedasharray", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"strokedashoffset", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"strokelinecap", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: false, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"strokelinejoin", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: false, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"strokemiterlimit", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"strokeopacity", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"strokewidth", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"surfacescale", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"systemlanguage", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"tablevalues", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"targetx", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"targety", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"textanchor", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"textdecoration", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"textlength", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"textrendering", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"to", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"transform", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"u1", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"u2", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"underlineposition", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"underlinethickness", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"unicode", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"unicodebidi", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"unicoderange", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"unitsperem", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"valphabetic", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"values", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"vectoreffect", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"version", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"vertadvy", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"vertoriginx", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"vertoriginy", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"vhanging", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"videographic", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"viewbox", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"viewtarget", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"visibility", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"vmathematical", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"widths", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"wordspacing", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"writingmode", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"x1", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"x2", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"x", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"xchannelselector", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"xheight", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"xlinkactuate", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"xlinkarcrole", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"xlinkhref", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"xlinkrole", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"xlinkshow", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"xlinktitle", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"xlinktype", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"xmlbase", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"xmllang", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"xmlns", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"xmlnsxlink", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"xmlspace", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"y1", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"y2", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"y", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"ychannelselector", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"z", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });

    m.insert(b"zoomandpan", ByNamespace {
      html: None,
      svg: Some(AttrMapEntry::AllNamespaceElements(AttributeMinification { boolean: false, redundant_if_empty: true, collapse_and_trim: false, default_value: None })),
    });


    AttrMap::new(m)
  };
}